Authors
=======

.. image:: https://img.shields.io/github/contributors/pyvista/pyvista.svg?logo=github&logoColor=white
   :target: https://github.com/pyvista/pyvista/graphs/contributors/

.. _authors_ref:

.. include:: ../AUTHORS.rst



License
-------

.. include:: ../LICENSE
